const fs = require('fs');
const path = require('path');
const schedule = require('node-schedule');
const cronParser = require('cron-parser');
const { parseCustomSchedule } = require('./utils');
const { executeTask } = require('./taskExecutor');
const { sendMessage } = require('./utils');

// 配置文件路径
const configPath = path.join(__dirname, '../tasks.json'); 

// 存储所有调度的任务
let scheduledJobs = {};

// 加载任务配置文件
function loadTasks() {
    try {
        const data = fs.readFileSync(configPath, 'utf8'); // 使用模块范围内的 configPath
        return JSON.parse(data);
    } catch (err) {
        sendMessage(null, `加载配置文件失败: ${err.message}`, 'error');
        return {};
    }
}

// 调度所有任务
async function scheduleTasks() {
    const tasks = loadTasks(); // 从固定路径加载任务配置

    Object.entries(tasks).forEach(([taskName, task]) => {
        const scheduleTime = task["Schedule"];
        let cronExpression, nextExecutionTime;

        try {
            cronExpression = parseCustomSchedule(scheduleTime); // 自定义解析
            const interval = cronParser.parseExpression(cronExpression);
            nextExecutionTime = interval.next().toString();
        } catch (err) {
            sendMessage(null, `任务 ${taskName} 时间解析失败: ${err.message}`, 'error');
            return;
        }

        sendMessage(
            null,
            `任务已调度: ${taskName} (时间: ${scheduleTime}) -> Cron: (${cronExpression}), 下次运行时间: ${nextExecutionTime}`,
            'info'
        );

        // 调度任务并存储引用
        const job = schedule.scheduleJob(cronExpression, async () => {
            await executeTask(taskName, task);
        });
        scheduledJobs[taskName] = job;
    });
}

// 清理所有已调度任务
function clearScheduledTasks() {
    Object.values(scheduledJobs).forEach((job) => job.cancel()); // 取消所有任务
    scheduledJobs = {}; // 清空任务记录
    sendMessage(null, `已清理所有现有任务`, 'info');
}

// 重新加载任务
async function reloadTasks() {
    clearScheduledTasks(); // 清理现有任务
    await scheduleTasks(); // 重新加载和调度任务
    sendMessage(null, `任务已重新加载完成！`, 'info');
}

module.exports = { scheduleTasks, reloadTasks };
