function sendMessage(player, message, type = 'info') {
    if (player) {
        player.tell(`[SchedTask] ${message}`, 0);
    } else {
        switch (type) {
            case 'error': logger.error(message); break;
            case 'warn': logger.warn(message); break;
            case 'debug': logger.debug(message); break;
            default: logger.info(message); break;
        }
    }
}


function parseCustomSchedule(schedule) {
    // Cron 表达式
    const cronRegex = /^((\*|([0-5]?\d)|([0-5]?\d-[0-5]?\d)|(\*\/\d+))( (\*|([0-5]?\d)|([0-5]?\d-[0-5]?\d)|(\*\/\d+))){4,6})$/;

    // 自定义时间格式解析逻辑
    if (schedule.startsWith("s:")) {
        const seconds = Number(schedule.split(":")[1]);
        if (seconds < 1 || seconds > 59) {
            throw new Error(`无效的每秒格式: ${schedule}。秒数间隔应为 1-59。`);
        }
        return `*/${seconds} * * * * *`; // 每隔 N 秒
    } else if (schedule.startsWith("d:")) {
        const [hour, minute] = schedule.slice(2).split(":").map(Number);
        if (hour < 0 || hour > 23 || minute < 0 || minute > 59) {
            throw new Error(`无效的每天时间格式: ${schedule}。小时 (0-23)，分钟 (0-59)。`);
        }
        return `${minute} ${hour} * * *`; // 每天特定时间
    } else if (schedule.startsWith("h:")) {
        const hours = Number(schedule.split(":")[1]);
        if (hours < 1 || hours > 23) {
            throw new Error(`无效的每小时格式: ${schedule}。小时间隔应为 1-23。`);
        }
        return `0 */${hours} * * *`; // 每隔 N 小时
    } else if (schedule.startsWith("m:")) {
        const minutes = Number(schedule.split(":")[1]);
        if (minutes < 1 || minutes > 59) {
            throw new Error(`无效的每分钟格式: ${schedule}。分钟间隔应为 1-59。`);
        }
        return `*/${minutes} * * * *`; // 每隔 N 分钟
    } else if (schedule.startsWith("w:")) {
        const [day, time] = schedule.slice(2).split("-");
        const [hour, minute] = time.split(":").map(Number);
        if (!["0", "1", "2", "3", "4", "5", "6"].includes(day) || hour < 0 || hour > 23 || minute < 0 || minute > 59) {
            throw new Error(`无效的每周时间格式: ${schedule}。星期天数 (0-6)，小时 (0-23)，分钟 (0-59)。`);
        }
        return `${minute} ${hour} * * ${day}`; // 每周指定时间
    } else if (schedule.startsWith("mon:")) {
        const [day, time] = schedule.slice(4).split("-");
        const [hour, minute] = time.split(":").map(Number);
        if (day < 1 || day > 31 || hour < 0 || hour > 23 || minute < 0 || minute > 59) {
            throw new Error(`无效的每月时间格式: ${schedule}。日期 (1-31)，小时 (0-23)，分钟 (0-59)。`);
        }
        return `${minute} ${hour} ${day} * *`; // 每月指定时间
    } else if (cronRegex.test(schedule)) {
        return schedule; // 如果匹配标准 Cron 表达式，直接返回
    } else {
        throw new Error(`无法识别的时间格式 "${schedule}"。支持格式：
        1. 标准 Cron 表达式（如 "*/5 * * * *"）
        2. 自定义格式：
           - 每秒 (s:N)
           - 每天特定时间 (d:HH:MM)
           - 每小时 (h:N)
           - 每分钟 (m:N)
           - 每周特定时间 (w:D-HH:MM)
           - 每月特定时间 (mon:D-HH:MM)
        `);
    }
}



module.exports = { sendMessage, parseCustomSchedule };
